'*************************************
'* Peek-A-Boo Ghost Waving Version   *
'* From Nuts and Volts Magazine      *
'* September 2014, Halloween Issue   * 
'* by Kevin Goodwin & Vern Graner    *
'* **********************************************************
'* V1.0a | Jul 07, 2014 | Code Created
'* V1.1b | Jul 25, 2014 | Verbose commenting added
'* V1.1c | Jul 25, 2014 | add "servo off" to save power
'* **********************************************************

' Pin Connection guide:
' ***************************************************
'     pin c.0 - LEDEyes 
'     pin c.1 - SERVO LEFT ARM
'     pin c.2 - SERVO RIGHT ARM
'     pin c.3 - PIR input
'     pin C.4 - Soundcard 

'*** Program Constants
	symbol Servo_delay     = 5    ' Delay to slow down servo motion, 0=wave fast 30= wave slow
	symbol Servo_min       = 120  ' \Set these values based on your servos
	symbol Servo_MAX       = 180  ' /
	symbol Retrigger_Delay = 5000 ' 5K ms is 5 seconds
      symbol True            = 1    ' \
      symbol False           = 0    ' /Used for comparisons
      
'*** Pin name assignments
      symbol LEDeyes     = c.0  ' LED eyes
      symbol RightArm    = c.1  ' Servo 
      symbol LeftArm     = c.2  ' Servo 
      symbol PIRSense    = pin3 ' PIR motion sensor 
      symbol Soundcard   = c.4  ' Audio Card

'*** init 
      HIGH LEDeyes              ' Turn off the LED eyes
      LOW SoundCard             ' Set sound card output to known off state

'*** Main program loop
MainLoop:

  WaitForTrigger:
  IF PIRsense = False then WaitForTrigger ' waiting for PIR motion sensor
 
  Wave_Arms:
  LOW LEDEyes                             '  Turn on LED eyes
  HIGH SoundCard                          '\ _Pulse line to voice card to start playback
  LOW SoundCard                           '/ 

  SERVO LeftARM,Servo_MAX                 '\_Start servo PWM output
  SERVO RightARM,Servo_Min                '/

  FOR b2 = 1 to 5                         ' Perform 5 sets of back/forth motions (change to taste)
  	LET b3 = Servo_MAX                ' B3 variable is used for left arm, B1 for right arm
	
  	FOR b1 = Servo_MIN to Servo_MAX   ' Move arms outward
  		ServoPOS RightARM,b1
		  let b3=b3-1
		  ServoPOS LeftARM,b3
		  PAUSE Servo_Delay
	  NEXT b1
	
  	FOR b1 = Servo_MAX to Servo_MIN step -1 'Move arms inward
  		servopos RightARM,b1
  		let b3=b3+1
  		servopos LeftARM,b3
 		PAUSE Servo_Delay
  	NEXT b1

  NEXT b2

  SERVOPOS RightArm,OFF      '\ Stop the servo PWM output to avoid
  SERVOPOS LeftArm,OFF       '/ jitter and reduce power consumption

  PAUSE Retrigger_Delay      ' wait a bit for motion to cease
                             ' To prevent "re triggering" or

  HIGH LEDEyes               ' Turn off LED eyes.

GOTO MainLoop
	
		